.. _api:

###
API
###

***********
SCIPR Model
***********

.. autoclass:: scipr.SCIPR
   :members:

******************
Matching Functions
******************

=======
Closest
=======

.. autoclass:: scipr.matching.Closest

======
Greedy
======

.. autoclass:: scipr.matching.Greedy

===
MNN
===

.. autoclass:: scipr.matching.MNN

=========
Hungarian
=========

.. autoclass:: scipr.matching.Hungarian

************************
Transformation Functions
************************

=====
Rigid
=====

.. autoclass:: scipr.transform.Rigid

======
Affine
======

.. autoclass:: scipr.transform.Affine

==================
StackedAutoEncoder
==================

.. autoclass:: scipr.transform.StackedAutoEncoder